@@ -181,7 +181,7 @@ class _TransactionFactory(object):
             (k, _Default(None)) for k in [
                 'db_max_retries', 'db_inc_retry_interval',
                 'use_db_reconnect',
-                'db_retry_interval', 'min_pool_size',
+                'db_retry_interval',
                 'db_max_retry_interval', 'backend', 'use_tpool'])
 
         self._started = False
@@ -1003,10 +1003,13 @@ class _TransactionContextManager(object):
             context_index = 1
         else:
             context_index = 0
+        context_kw = argspec.args[context_index]
 
         @functools.wraps(fn)
         def wrapper(*args, **kwargs):
-            context = args[context_index]
+            context = kwargs.get(context_kw, None)
+            if not context:
+                context = args[context_index]
 
             with self._transaction_scope(context):
                 return fn(*args, **kwargs)
